/* $Id: detmon_dfs.c,v 1.1.1.1 2007/04/17 13:40:30 lbilbao Exp $
 *
 * This file is part of the IIINSTRUMENT Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: lbilbao $
 * $Date: 2007/04/17 13:40:30 $
 * $Revision: 1.1.1.1 $
 * $Name: HEAD $
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*-----------------------------------------------------------------------------
   								Includes
 -----------------------------------------------------------------------------*/

#include <string.h>
#include <math.h>

#include <cpl.h>

#include "detmon_dfs.h"

/*----------------------------------------------------------------------------*/
/**
 * @defgroup iiinstrument_dfs  DFS related functions
 *
 * TBD
 */
/*----------------------------------------------------------------------------*/

/**@{*/

/*----------------------------------------------------------------------------*/
/**
  @brief    Set the group as RAW or CALIB in a frameset
  @param    set     the input frameset
  @return   0 if ok, -1 in error case
 */
/*----------------------------------------------------------------------------*/
int detmon_dfs_set_groups(cpl_frameset * set)
{
    cpl_frame   *   cur_frame ;
    const char  *   tag ;
    int             nframes ;
    int             i ;

    /* Check entries */
    if (set == NULL) return -1 ; 
    
    /* Initialize */
    nframes = cpl_frameset_get_size(set) ;

    /* Loop on frames */
    for (i=0 ; i<nframes ; i++) {
        cur_frame = cpl_frameset_get_frame(set, i) ;
        tag = cpl_frame_get_tag(cur_frame) ;
       
        /* RAW frames */
        if (!strcmp(tag, DETMON_IR_LG_ON_RAW) || !strcmp(tag, DETMON_IR_LG_OFF_RAW))
            cpl_frame_set_group(cur_frame, CPL_FRAME_GROUP_RAW) ;
        /* CALIB frames */
/*        else if (!strcmp(tag, IIINSTRUMENT_CALIB_FLAT))
            cpl_frame_set_group(cur_frame, CPL_FRAME_GROUP_CALIB) ;
*/
    }
    return 0 ;
}

/**@}*/
